Module proxy

Module proxy 

Functions

check_sandbox_access
Check if a set of scopes allows access to a sandbox.
check_write_access
Check if a set of scopes allows write access.
extract_sandbox_id_from_path
Extract sandbox ID from a path-based proxy URL (/sandbox/<id>/...).
strip_sandbox_prefix
Strip the /sandbox/<id> prefix from a path, returning the remainder.