Functions
- check_
sandbox_ access - Check if a set of scopes allows access to a sandbox.
- check_
write_ access - Check if a set of scopes allows write access.
- extract_
sandbox_ id_ from_ path - Extract sandbox ID from a path-based proxy URL (
/sandbox/<id>/...). - strip_
sandbox_ prefix - Strip the
/sandbox/<id>prefix from a path, returning the remainder.